@@ -348,29 +348,3 @@ class Job:
         # TODO: check that this is best practice for killing a job.
         self.proc.resume()
         self.proc.terminate()
-
-
-def report_jdata(jobs, tmp_prefix='', dst_prefix='') -> list:
-    jobsr = list()
-    for i, j in enumerate(sorted(jobs, key=Job.get_time_wall)):
-        with j.proc.oneshot():
-            dictionary = {
-                'plotid': j.plot_id_prefix,
-                'k': j.k,
-                'tmp': plot_util.abbr_path(j.tmpdir, tmp_prefix),
-                'dst': plot_util.abbr_path(j.dstdir, dst_prefix),
-                'wall': plot_util.time_format(j.get_time_wall()),
-                'phase': plot_util.phase_str(j.progress()),
-                'tmpdisk': plot_util.human_format(j.get_tmp_usage(), 0),
-                'pid': j.proc.pid,
-                'stat': j.get_run_status(),
-                'mem': plot_util.human_format(j.get_mem_usage(), 1),
-                'user': plot_util.time_format(j.get_time_user()),
-                'sys': plot_util.time_format(j.get_time_sys()),
-                'io': plot_util.time_format(j.get_time_iowait()),
-                'freezed': plot_util.is_freezed(j),
-                'logfile': os.path.basename(j.getLogPath)
-            }
-            jobsr.append(dictionary)
-
-    return jobsr
